==> schemacrawler-14.17.05-sources.jar: schemacrawler/schema/IndexType.java <==
/*
========================================================================
SchemaCrawler
http://www.schemacrawler.com
Copyright (c) 2000-2018, Sualeh Fatehi <sualeh@hotmail.com>.
All rights reserved.
------------------------------------------------------------------------

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

SchemaCrawler and the accompanying materials are made available under
the terms of the Eclipse Public License v1.0, GNU General Public License
v3 or GNU Lesser General Public License v3.

You may elect to redistribute this code under any of these licenses.

The Eclipse Public License is available at:
http://www.eclipse.org/legal/epl-v10.html

The GNU General Public License v3 and the GNU Lesser General Public
License v3 are available at:
http://www.gnu.org/licenses/

========================================================================
*/

package schemacrawler.schema;


import java.sql.DatabaseMetaData;

import sf.util.IdentifiedEnum;

/**
 * An enumeration wrapper around index types.
 */
public enum IndexType
  implements
  IdentifiedEnum
{

 /**
  * Unknown
  */
 unknown(-1),
 /**
  * Statistic.
  */
 statistic(DatabaseMetaData.tableIndexStatistic),
 /**
  * Clustered.
  */
 clustered(DatabaseMetaData.tableIndexClustered),
 /**
  * Hashed.
  */
 hashed(DatabaseMetaData.tableIndexHashed),
 /**
  * Other.
  */
 other(DatabaseMetaData.tableIndexOther);

  private final int id;

  private IndexType(final int id)
  {
    this.id = id;
  }

  /**
   * Gets the id.
   *
   * @return id
   */
  @Override
  public int getId()
  {
    return id;
  }

}

==> schemacrawler-16.18.2-sources.jar: schemacrawler/schema/IndexType.java <==
/*
========================================================================
SchemaCrawler
http://www.schemacrawler.com
Copyright (c) 2000-2022, Sualeh Fatehi <sualeh@hotmail.com>.
All rights reserved.
------------------------------------------------------------------------

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

SchemaCrawler and the accompanying materials are made available under
the terms of the Eclipse Public License v1.0, GNU General Public License
v3 or GNU Lesser General Public License v3.

You may elect to redistribute this code under any of these licenses.

The Eclipse Public License is available at:
http://www.eclipse.org/legal/epl-v10.html

The GNU General Public License v3 and the GNU Lesser General Public
License v3 are available at:
http://www.gnu.org/licenses/

========================================================================
*/

package schemacrawler.schema;

import static java.sql.DatabaseMetaData.tableIndexClustered;
import static java.sql.DatabaseMetaData.tableIndexHashed;
import static java.sql.DatabaseMetaData.tableIndexOther;
import static java.sql.DatabaseMetaData.tableIndexStatistic;

/** An enumeration wrapper around index types. */
public enum IndexType implements IdentifiedEnum {
  unknown(-1),
  statistic(tableIndexStatistic),
  clustered(tableIndexClustered),
  hashed(tableIndexHashed),
  other(tableIndexOther);

  private final int id;

  IndexType(final int id) {
    this.id = id;
  }

  /** {@inheritDoc} */
  @Override
  public int id() {
    return id;
  }
}
